==> nextcloud-16.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files/l10n/sr.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Складиште привремено није  доступно",
    "Storage invalid" : "Неисправно складиште",
    "Unknown error" : "Непозната грешка",
    "All files" : "Сви фајлови",
    "Recent" : "Скорашњи",
    "Favorites" : "Омиљени",
    "File could not be found" : "Фајл није нађен",
    "Move or copy" : "Помери или копирај",
    "Download" : "Преузми",
    "Delete" : "Обриши",
    "Home" : "Почетна",
    "Close" : "Затвори",
    "Could not create folder \"{dir}\"" : "Не могу да направим фасциклу \"{dir}\"",
    "This will stop your current uploads." : "Ово ће да прекине тренутна отпремања.",
    "Upload cancelled." : "Отпремање је отказано.",
    "Processing files …" : "Обрађујем фајлове…",
    "…" : "…",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Не могу да отпремим {filename} јер је то или директоријум или има 0 бајтова",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Нема простора. Отпремате {size1} али само {size2} је преостало",
    "Target folder \"{dir}\" does not exist any more" : "Одредишна фасцикла \"{dir}\" више не постоји",
    "Not enough free space" : "Нема довољно слободног места",
    "An unknown error has occurred" : "Десила се непозната грешка",
    "Uploading …" : "Отпремам…",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} од {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "Отпремање те ставке није подржано",
    "Target folder does not exist any more" : "Одредишна фасцикла више не постоји",
    "Error when assembling chunks, status code {status}" : "Грешки при прикупљању делова фајла, статус код {status}",
    "Actions" : "Радње",
    "Rename" : "Преименуј",
    "Copy" : "Копирај",
    "Choose target folder" : "Одаберите одредишну фасциклу",
    "Open" : "Отвори",
    "Disconnect storage" : "Искључи складиште",
    "Unshare" : "Укини дељење",
    "Could not load info for file \"{file}\"" : "Не могу да учитам информације фајла \"{file}\"",
    "Files" : "Фајлови",
    "Details" : "Детаљи",
    "Select" : "Изабери",
    "Pending" : "На чекању",
    "Unable to determine date" : "Не могу да одредим датум",
    "This operation is forbidden" : "Ова радња је забрањена",
    "This directory is unavailable, please check the logs or contact the administrator" : "Овај директоријум није доступан, проверите записе или контактирајте администратора",
    "Could not move \"{file}\", target exists" : "Не могу да померим \"{file}\", одредиште већ постоји",
    "Could not move \"{file}\"" : "Не могу да померим \"{file}\"",
    "copy" : "копиран",
    "Could not copy \"{file}\", target exists" : "Не могу да копирам \"{file}\", одредиште већ постоји",
    "Could not copy \"{file}\"" : "Не могу да копирам \"{file}\"",
    "Copied {origin} inside {destination}" : "Копиран {origin} у {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "Копиран{origin} и још {nbfiles} других фајлова у {destination}",
    "{newName} already exists" : "{newName} већ постоји",
    "Could not rename \"{fileName}\", it does not exist any more" : "Не могу да преименујем \"{fileName}\", фајл више не постоји",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Име \"{targetName}\" се већ користи за фасциклу \"{dir}\". Одаберите неко друго име.",
    "Could not rename \"{fileName}\"" : "Не могу да преименујем \"{fileName}\"",
    "Could not create file \"{file}\"" : "Не могу да направим фајл \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Не могу да направим фајл \"{file}\" јер већ постоји",
    "Could not create folder \"{dir}\" because it already exists" : "Не могу да направим фасциклу \"{dir}\" јер већ постоји",
    "Error deleting file \"{fileName}\"." : "Грешка при брисању фајла \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "Нема резултата претраге у осталим фасциклама за {tag}{filter}{endtag}",
    "Name" : "Назив",
    "Size" : "Величина",
    "Modified" : "Измењен",
    "_%n folder_::_%n folders_" : ["%n фасцикла","%n фасцикле","%n фасцикли"],
    "_%n file_::_%n files_" : ["%n фајл","%n фајла","%n фајлова"],
    "{dirs} and {files}" : "{dirs} и {files}",
    "_including %n hidden_::_including %n hidden_" : ["укључујући и %n скривени","укључујући и %n скривена","укључујући и %n скривених"],
    "You don’t have permission to upload or create files here" : "Немате дозволе да овде отпремате или стварате фајлове",
    "_Uploading %n file_::_Uploading %n files_" : ["Отпремам %n фајл","Отпремам %n фајла","Отпремам %n фајлова"],
    "New" : "Ново",
    "Select file range" : "Одаберите опсег фајлова",
    "{used} of {quota} used" : "{used} од {quota} искоришћено",
    "{used} used" : "{used} искоришћено",
    "\"{name}\" is an invalid file name." : "\"{name}\" није исправан назив фајла.",
    "File name cannot be empty." : "Назив фајла не може бити празан.",
    "\"/\" is not allowed inside a file name." : "\"/\" није дозвољен каракетер у имену фајла.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" није дозвољени тип фајла",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Складиште корисника {owner} је пуно. Фајлови се не могу ажурирати нити синхронизовати!",
    "Your storage is full, files can not be updated or synced anymore!" : "Ваше складиште је пуно. Фајлови више не могу бити ажурирани ни синхронизовани!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Складиште корисника {owner} је скоро пуно ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Ваше складиште је скоро пуно ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["се поклапа са '{filter}'","се поклапају са '{filter}'","се поклапа са '{filter}'"],
    "View in folder" : "Види у фасцикли",
    "Copied!" : "Копирано!",
    "Copy direct link (only works for users who have access to this file/folder)" : "Копирај директну везу (ради само за кориснике који имају приступ овом фајлу/фасциклу)",
    "Path" : "Путања",
    "_%n byte_::_%n bytes_" : ["%n бајт","%n бајта","%n бајтова"],
    "Favorited" : "Омиљено",
    "Favorite" : "Омиљени",
    "You can only favorite a single file or folder at a time" : "Можете поставити као омиљени само један фајл или фасциклу одједном",
    "New folder" : "Нова фасцикла",
    "Upload file" : "Отпреми фајл",
    "Not favorited" : "Није омиљено",
    "Remove from favorites" : "Избаци из омиљених",
    "Add to favorites" : "Додај у омиљене",
    "An error occurred while trying to update the tags" : "Дошло је до грешке при покушају ажурирања ознака",
    "Added to favorites" : "Додато у омиљено",
    "Removed from favorites" : "Избачено из омиљених",
    "You added {file} to your favorites" : "Додали сте {file} у омиљене",
    "You removed {file} from your favorites" : "Избацили сте {file} из омиљених",
    "File changes" : "Измене над фајлом",
    "Created by {user}" : "Направио {user}",
    "Changed by {user}" : "Изменио {user}",
    "Deleted by {user}" : "Обрисао {user}",
    "Restored by {user}" : "Повратио {user}",
    "Renamed by {user}" : "Преименовао {user}",
    "Moved by {user}" : "Померио {user}",
    "\"remote user\"" : "„удаљени корисник“",
    "You created {file}" : "Направили сте {file}",
    "You created an encrypted file in {file}" : "Направили сте шифровани фајл {file}",
    "{user} created {file}" : "{user} је направио {file}",
    "{user} created an encrypted file in {file}" : "{user} је направио шифровани фајл {file}",
    "{file} was created in a public folder" : "{file} је направљен у јавној фасцикли",
    "You changed {file}" : "Изменили сте {file}",
    "You changed an encrypted file in {file}" : "Изменили сте шифровани фајл {file}",
    "{user} changed {file}" : "{user} је изменио {file}",
    "{user} changed an encrypted file in {file}" : "{user} је изменио шифровани фајл {file}",
    "You deleted {file}" : "Обрисали сте {file}",
    "You deleted an encrypted file in {file}" : "Обрисали сте шифровани фајл {file}",
    "{user} deleted {file}" : "{user} је обрисао {file}",
    "{user} deleted an encrypted file in {file}" : "{user} је обрисао шифровани фајл {file}",
    "You restored {file}" : "Повратили сте {file}",
    "{user} restored {file}" : "{user} је повратио {file}",
    "You renamed {oldfile} to {newfile}" : "Преименовали сте {oldfile} на {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} је преименовао {oldfile} на {newfile}",
    "You moved {oldfile} to {newfile}" : "Померили сте {oldfile} на {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} је померио {oldfile} на {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Фајл је додат или избрисан из Ваших <strong>омиљених</strong>",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Фајл или фасцикла су <strong>измењени</strong> или <strong>преименовани</strong>",
    "A new file or folder has been <strong>created</strong>" : "Нови фајл или фасцикла су <strong>направљени</strong>",
    "A file or folder has been <strong>deleted</strong>" : "Фајл или фасцикла су <strong>обрисани</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Ограничи обавештења о стварању и изменама на <strong>омиљене фајлове</strong> <em>(само у записнику)</em>",
    "A file or folder has been <strong>restored</strong>" : "Фајл или фасцикла су <strong>враћени</strong>",
    "Unlimited" : "Неограничено",
    "Upload (max. %s)" : "Отпремање (макс. %s)",
    "File Management" : "Управљање фајловима",
    "%s used" : "%s искоришћено",
    "%s%% of %s used" : "%s%% од %s искоришћено",
    "%1$s of %2$s used" : "Заузето %1$s од %2$s",
    "Settings" : "Поставке",
    "Show hidden files" : "Прикажи скривене фајлове",
    "WebDAV" : "ВебДАВ",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">access your Files via WebDAV</a>" : "Користи ову адресу да <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">приступате Вашим фајловима преко ВебДАВа</a>",
    "Toggle grid view" : "Укључи/искључи приказ мреже",
    "No files in here" : "Овде нема фајлова",
    "Upload some content or sync with your devices!" : "Отпремите неки садржај или синхронизујте са вашим уређајима!",
    "No entries found in this folder" : "Нема ничега у овој фасцикли",
    "Select all" : "Означи све",
    "Upload too large" : "Фајл за отпремање је превелики",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Фајлови које желите да отпремите превазилазе ограничење отпремања на овом серверу.",
    "No favorites yet" : "Још нема омиљених",
    "Files and folders you mark as favorite will show up here" : "Фајлови и фасцикле које обележите као омиљене појавиће се овде",
    "Tags" : "Ознаке",
    "Deleted files" : "Обрисани фајлови",
    "Shares" : "Дељења",
    "Shared with others" : "Дељени са осталима",
    "Shared with you" : "Дељени са вама",
    "Shared by link" : "Дељени путем везе",
    "Deleted shares" : "Обрисана дељења",
    "Text file" : "Tекстуални фајл",
    "New text file.txt" : "Нов текстуални фајл.txt",
    "Target folder" : "Одредишна фасцикла",
    "File handling" : "Руковање фајловима",
    "Maximum upload size" : "Највећа величина отпремања",
    "max. possible: " : "највише могуће:",
    "Save" : "Сачувај",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Ако користите PHP-FPM, промене се могу применити и тек после 5 минута.",
    "Missing permissions to edit from here." : "Недостају дозволе да се мења одавде.",
    "%s of %s used" : "%s од %s искоришћено",
    "Cancel upload" : "Откажи отпремање",
    "%1$s%% of %2$s used" : "%1$s%% од %2$s искоришћено"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> nextcloud-17.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files/l10n/sr.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Складиште привремено није  доступно",
    "Storage invalid" : "Неисправно складиште",
    "Unknown error" : "Непозната грешка",
    "All files" : "Сви фајлови",
    "Recent" : "Скорашњи",
    "Favorites" : "Омиљени",
    "File could not be found" : "Фајл није нађен",
    "Move or copy" : "Помери или копирај",
    "Download" : "Преузми",
    "Delete" : "Обриши",
    "Home" : "Почетна",
    "Close" : "Затвори",
    "Could not create folder \"{dir}\"" : "Не могу да направим фасциклу \"{dir}\"",
    "This will stop your current uploads." : "Ово ће да прекине тренутна отпремања.",
    "Upload cancelled." : "Отпремање је отказано.",
    "Processing files …" : "Обрађујем фајлове…",
    "…" : "…",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Не могу да отпремим {filename} јер је то или директоријум или има 0 бајтова",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Нема простора. Отпремате {size1} али само {size2} је преостало",
    "Target folder \"{dir}\" does not exist any more" : "Одредишна фасцикла \"{dir}\" више не постоји",
    "Not enough free space" : "Нема довољно слободног места",
    "An unknown error has occurred" : "Десила се непозната грешка",
    "Uploading …" : "Отпремам…",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} од {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "Отпремање те ставке није подржано",
    "Target folder does not exist any more" : "Одредишна фасцикла више не постоји",
    "Error when assembling chunks, status code {status}" : "Грешки при прикупљању делова фајла, статус код {status}",
    "Actions" : "Радње",
    "Rename" : "Преименуј",
    "Copy" : "Копирај",
    "Choose target folder" : "Одаберите одредишну фасциклу",
    "Open" : "Отвори",
    "Delete file" : "Обриши фајл",
    "Delete folder" : "Обриши фасциклу",
    "Disconnect storage" : "Искључи складиште",
    "Unshare" : "Укини дељење",
    "Could not load info for file \"{file}\"" : "Не могу да учитам информације фајла \"{file}\"",
    "Files" : "Фајлови",
    "Details" : "Детаљи",
    "Select" : "Изабери",
    "Pending" : "На чекању",
    "Unable to determine date" : "Не могу да одредим датум",
    "This operation is forbidden" : "Ова радња је забрањена",
    "This directory is unavailable, please check the logs or contact the administrator" : "Овај директоријум није доступан, проверите записе или контактирајте администратора",
    "Could not move \"{file}\", target exists" : "Не могу да померим \"{file}\", одредиште већ постоји",
    "Could not move \"{file}\"" : "Не могу да померим \"{file}\"",
    "copy" : "копиран",
    "Could not copy \"{file}\", target exists" : "Не могу да копирам \"{file}\", одредиште већ постоји",
    "Could not copy \"{file}\"" : "Не могу да копирам \"{file}\"",
    "Copied {origin} inside {destination}" : "Копиран {origin} у {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "Копиран{origin} и још {nbfiles} других фајлова у {destination}",
    "{newName} already exists" : "{newName} већ постоји",
    "Could not rename \"{fileName}\", it does not exist any more" : "Не могу да преименујем \"{fileName}\", фајл више не постоји",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Име \"{targetName}\" се већ користи за фасциклу \"{dir}\". Одаберите неко друго име.",
    "Could not rename \"{fileName}\"" : "Не могу да преименујем \"{fileName}\"",
    "Could not create file \"{file}\"" : "Не могу да направим фајл \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Не могу да направим фајл \"{file}\" јер већ постоји",
    "Could not create folder \"{dir}\" because it already exists" : "Не могу да направим фасциклу \"{dir}\" јер већ постоји",
    "Error deleting file \"{fileName}\"." : "Грешка при брисању фајла \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "Нема резултата претраге у осталим фасциклама за {tag}{filter}{endtag}",
    "Name" : "Назив",
    "Size" : "Величина",
    "Modified" : "Измењен",
    "_%n folder_::_%n folders_" : ["%n фасцикла","%n фасцикле","%n фасцикли"],
    "_%n file_::_%n files_" : ["%n фајл","%n фајла","%n фајлова"],
    "{dirs} and {files}" : "{dirs} и {files}",
    "_including %n hidden_::_including %n hidden_" : ["укључујући и %n скривени","укључујући и %n скривена","укључујући и %n скривених"],
    "You don’t have permission to upload or create files here" : "Немате дозволе да овде отпремате или стварате фајлове",
    "_Uploading %n file_::_Uploading %n files_" : ["Отпремам %n фајл","Отпремам %n фајла","Отпремам %n фајлова"],
    "New" : "Ново",
    "Select file range" : "Одаберите опсег фајлова",
    "{used} of {quota} used" : "{used} од {quota} искоришћено",
    "{used} used" : "{used} искоришћено",
    "\"{name}\" is an invalid file name." : "\"{name}\" није исправан назив фајла.",
    "File name cannot be empty." : "Назив фајла не може бити празан.",
    "\"/\" is not allowed inside a file name." : "\"/\" није дозвољен каракетер у имену фајла.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" није дозвољени тип фајла",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Складиште корисника {owner} је пуно. Фајлови се не могу ажурирати нити синхронизовати!",
    "Your storage is full, files can not be updated or synced anymore!" : "Ваше складиште је пуно. Фајлови више не могу бити ажурирани ни синхронизовани!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Складиште корисника {owner} је скоро пуно ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Ваше складиште је скоро пуно ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["се поклапа са '{filter}'","се поклапају са '{filter}'","се поклапа са '{filter}'"],
    "View in folder" : "Види у фасцикли",
    "Copied!" : "Копирано!",
    "Copy direct link (only works for users who have access to this file/folder)" : "Копирај директну везу (ради само за кориснике који имају приступ овом фајлу/фасциклу)",
    "Path" : "Путања",
    "_%n byte_::_%n bytes_" : ["%n бајт","%n бајта","%n бајтова"],
    "Favorited" : "Омиљено",
    "Favorite" : "Омиљени",
    "You can only favorite a single file or folder at a time" : "Можете поставити као омиљени само један фајл или фасциклу одједном",
    "New folder" : "Нова фасцикла",
    "Upload file" : "Отпреми фајл",
    "Not favorited" : "Није омиљено",
    "Remove from favorites" : "Избаци из омиљених",
    "Add to favorites" : "Додај у омиљене",
    "An error occurred while trying to update the tags" : "Дошло је до грешке при покушају ажурирања ознака",
    "Added to favorites" : "Додато у омиљено",
    "Removed from favorites" : "Избачено из омиљених",
    "You added {file} to your favorites" : "Додали сте {file} у омиљене",
    "You removed {file} from your favorites" : "Избацили сте {file} из омиљених",
    "File changes" : "Измене над фајлом",
    "Created by {user}" : "Направио {user}",
    "Changed by {user}" : "Изменио {user}",
    "Deleted by {user}" : "Обрисао {user}",
    "Restored by {user}" : "Повратио {user}",
    "Renamed by {user}" : "Преименовао {user}",
    "Moved by {user}" : "Померио {user}",
    "\"remote user\"" : "„удаљени корисник“",
    "You created {file}" : "Направили сте {file}",
    "You created an encrypted file in {file}" : "Направили сте шифровани фајл {file}",
    "{user} created {file}" : "{user} је направио {file}",
    "{user} created an encrypted file in {file}" : "{user} је направио шифровани фајл {file}",
    "{file} was created in a public folder" : "{file} је направљен у јавној фасцикли",
    "You changed {file}" : "Изменили сте {file}",
    "You changed an encrypted file in {file}" : "Изменили сте шифровани фајл {file}",
    "{user} changed {file}" : "{user} је изменио {file}",
    "{user} changed an encrypted file in {file}" : "{user} је изменио шифровани фајл {file}",
    "You deleted {file}" : "Обрисали сте {file}",
    "You deleted an encrypted file in {file}" : "Обрисали сте шифровани фајл {file}",
    "{user} deleted {file}" : "{user} је обрисао {file}",
    "{user} deleted an encrypted file in {file}" : "{user} је обрисао шифровани фајл {file}",
    "You restored {file}" : "Повратили сте {file}",
    "{user} restored {file}" : "{user} је повратио {file}",
    "You renamed {oldfile} to {newfile}" : "Преименовали сте {oldfile} на {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} је преименовао {oldfile} на {newfile}",
    "You moved {oldfile} to {newfile}" : "Померили сте {oldfile} на {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} је померио {oldfile} на {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Фајл је додат или избрисан из Ваших <strong>омиљених</strong>",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Фајл или фасцикла су <strong>измењени</strong> или <strong>преименовани</strong>",
    "A new file or folder has been <strong>created</strong>" : "Нови фајл или фасцикла су <strong>направљени</strong>",
    "A file or folder has been <strong>deleted</strong>" : "Фајл или фасцикла су <strong>обрисани</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Ограничи обавештења о стварању и изменама на <strong>омиљене фајлове</strong> <em>(само у записнику)</em>",
    "A file or folder has been <strong>restored</strong>" : "Фајл или фасцикла су <strong>враћени</strong>",
    "Unlimited" : "Неограничено",
    "Upload (max. %s)" : "Отпремање (макс. %s)",
    "File Management" : "Управљање фајловима",
    "%s used" : "%s искоришћено",
    "%s%% of %s used" : "%s%% од %s искоришћено",
    "%1$s of %2$s used" : "Заузето %1$s од %2$s",
    "Settings" : "Поставке",
    "Show hidden files" : "Прикажи скривене фајлове",
    "WebDAV" : "ВебДАВ",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">access your Files via WebDAV</a>" : "Користи ову адресу да <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">приступате Вашим фајловима преко ВебДАВа</a>",
    "Toggle grid view" : "Укључи/искључи приказ мреже",
    "No files in here" : "Овде нема фајлова",
    "Upload some content or sync with your devices!" : "Отпремите неки садржај или синхронизујте са вашим уређајима!",
    "No entries found in this folder" : "Нема ничега у овој фасцикли",
    "Select all" : "Означи све",
    "Upload too large" : "Фајл за отпремање је превелики",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Фајлови које желите да отпремите превазилазе ограничење отпремања на овом серверу.",
    "No favorites yet" : "Још нема омиљених",
    "Files and folders you mark as favorite will show up here" : "Фајлови и фасцикле које обележите као омиљене појавиће се овде",
    "Tags" : "Ознаке",
    "Deleted files" : "Обрисани фајлови",
    "Shares" : "Дељења",
    "Shared with others" : "Дељени са осталима",
    "Shared with you" : "Дељени са вама",
    "Shared by link" : "Дељени путем везе",
    "Deleted shares" : "Обрисана дељења",
    "Text file" : "Tекстуални фајл",
    "New text file.txt" : "Нов текстуални фајл.txt",
    "File handling" : "Руковање фајловима",
    "Maximum upload size" : "Највећа величина отпремања",
    "max. possible: " : "највише могуће:",
    "Save" : "Сачувај",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Ако користите PHP-FPM, промене се могу применити и тек после 5 минута.",
    "Missing permissions to edit from here." : "Недостају дозволе да се мења одавде.",
    "Cancel upload" : "Откажи отпремање",
    "%s of %s used" : "%s од %s искоришћено",
    "%1$s%% of %2$s used" : "%1$s%% од %2$s искоришћено"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
